
# Slot: local_name_source


the ncname of the source of the name

URI: [linkml:local_name_source](https://w3id.org/linkml/local_name_source)


## Domain and Range

[LocalName](LocalName.md) &#8594;  <sub>1..1</sub> [Ncname](types/Ncname.md)

## Parents


## Children


## Used by

 * [LocalName](LocalName.md)
